/*
 * osdreader.c: A plugin for the Video Disk Recorder
 *
 *  (c) 2010 Jean-Christophe Duberga < jc AT duberga.net >
 * 
 * See the README file for copyright information and how to reach the author.
 *
 * $Id$
 */

#include <vdr/plugin.h>
#include "status.h"
#include "menu.h"

static const char *VERSION        = "0.0.1";
static const char *DESCRIPTION    = "Make OSD speaking";

class cPluginOsdReader : public cPlugin {
private:
  cStatusOsdReader * m_pStatusOsdReader;
public:
  cPluginOsdReader(void);
  virtual ~cPluginOsdReader();
  virtual const char *Version(void) { return VERSION; }
  virtual const char *Description(void) { return DESCRIPTION; }
  virtual const char *CommandLineHelp(void);
  virtual bool ProcessArgs(int argc, char *argv[]);
  virtual bool Initialize(void);
  virtual bool Start(void);
  virtual void Stop(void);
  virtual void Housekeeping(void);
  virtual void MainThreadHook(void);
  virtual cString Active(void);
  virtual time_t WakeupTime(void);
  virtual cMenuSetupPage *SetupMenu(void);
  virtual bool SetupParse(const char *Name, const char *Value);
  virtual bool Service(const char *Id, void *Data = NULL);
  virtual const char **SVDRPHelpPages(void);
  virtual cString SVDRPCommand(const char *Command, const char *Option, int &ReplyCode);
  };

cPluginOsdReader::cPluginOsdReader(void)
{
   m_pStatusOsdReader = NULL;
}

cPluginOsdReader::~cPluginOsdReader()
{
   if(m_pStatusOsdReader)
     delete m_pStatusOsdReader;
   m_pStatusOsdReader = NULL;
}

const char *cPluginOsdReader::CommandLineHelp(void)
{
  // Return a string that describes all known command line options.
  return NULL;
}

bool cPluginOsdReader::ProcessArgs(int argc, char *argv[])
{
  // Implement command line argument processing here if applicable.
  return true;
}

bool cPluginOsdReader::Initialize(void)
{
  // Initialize any background activities the plugin shall perform.
  return true;
}

bool cPluginOsdReader::Start(void)
{
   bool ret = false;
   
   m_pStatusOsdReader = new cStatusOsdReader();
   
   if (m_pStatusOsdReader)
     {
	ret = true;
     }
   
   return ret;   
}

void cPluginOsdReader::Stop(void)
{
  // Stop any background activities the plugin is performing.
}

void cPluginOsdReader::Housekeeping(void)
{
  // Perform any cleanup or other regular tasks.
}

void cPluginOsdReader::MainThreadHook(void)
{
  // Perform actions in the context of the main program thread.
  // WARNING: Use with great care - see PLUGINS.html!
}

cString cPluginOsdReader::Active(void)
{
   
//   esyslog("OsdReader plugin: A C T I V E");

  // Return a message string if shutdown should be postponed
  return NULL;
}

time_t cPluginOsdReader::WakeupTime(void)
{
  // Return custom wakeup time for shutdown script
  return 0;
}


cMenuSetupPage *cPluginOsdReader::SetupMenu(void)
{
   return new cSetupMenuOsdReader();
}

bool cPluginOsdReader::SetupParse(const char *Name, const char *Value)
{
   if     (!strcasecmp(Name, "active"))      OsdReaderSetup.active    = atoi(Value);
   else if(!strcasecmp(Name, "speed"))        
     {
	OsdReaderSetup.speed = atoi(Value); 
	OsdReaderSetup.speed = max(OsdReaderSetup.speed,OsdReaderSetup.speed_min);
	OsdReaderSetup.speed = min(OsdReaderSetup.speed,OsdReaderSetup.speed_max);
     }
   else if(!strcasecmp(Name, "volume"))
     {
	OsdReaderSetup.volume = atoi(Value); 
	OsdReaderSetup.volume = max(OsdReaderSetup.volume,OsdReaderSetup.volume_min);
	OsdReaderSetup.volume = min(OsdReaderSetup.volume,OsdReaderSetup.volume_max);
     }
   else if(!strcasecmp(Name, "voice"))      
     {    
	strncpy(OsdReaderSetup.voice,Value,sizeof(OsdReaderSetup.voice));
     }
   else if(!strcasecmp(Name, "say_channel"))
     {
	OsdReaderSetup.say_channel = atoi(Value);
     }
   else if(!strcasecmp(Name, "say_info"))
     {
	OsdReaderSetup.say_info = atoi(Value);
     }
   else if(!strcasecmp(Name, "say_menu"))
     {
	OsdReaderSetup.say_menu = atoi(Value);
     }
   else 
     return false;
   
   return true;
}

bool cPluginOsdReader::Service(const char *Id, void *Data)
{
  // Handle custom service requests from other plugins
  return false;
}

const char **cPluginOsdReader::SVDRPHelpPages(void)
{
  // Return help text for SVDRP commands this plugin implements
  return NULL;
}

cString cPluginOsdReader::SVDRPCommand(const char *Command, const char *Option, int &ReplyCode)
{
  // Process SVDRP commands this plugin implements
  return NULL;
}

VDRPLUGINCREATOR(cPluginOsdReader); // Don't touch this!
